.. _getting_started:


Getting started with MoviePy
------------------------------


These pages explain everything you need to start editing with MoviePy. To go further, have a look at the :ref:`gallery` and the :ref:`examples`.


.. toctree::
   :maxdepth: 1
   
   quick_presentation
   compositing
   effects
   efficient_moviepy
   working_with_matplotlib
   audioclips
   videoclips
